import os
import re
import logging

logging.basicConfig(filename="specularFixer.log", filemode="w", level=logging.DEBUG)

texture_cache = {}
for directory in os.walk("models"):
    relative_dirpath, dirs, files_list = directory
    if "SPECULARS_FIXED" in relative_dirpath:
        continue

    for filename in files_list:
        if filename.endswith(".t3d"):
            filepath = os.path.join(relative_dirpath, filename)
            logging.info("A T3D model was found in {}".format(filepath))

            output_filepath = os.path.join("SPECULARS_FIXED", filepath)
            logging.info("Fixed-specular model will be saved in {}".format(output_filepath))

            output_dirpath = os.path.dirname(output_filepath)

            if not os.path.exists(output_dirpath):
                os.makedirs(output_dirpath)
                logging.info("A new path was created: {}".format(output_dirpath))

            with open(filepath) as input_file:

                replacings = []
                textures_in_order = []
                for line in input_file:
                    if "specular" in line.lower():
                        old_specular = line.split(":")[1].strip()

                    if "map" in line.lower():
                        texture = line.split(":")[1].strip()

                        if texture.lower() != "none":
                            if texture not in texture_cache.keys():
                                new_specular = input("Tekstura: {}. Wpisz 3 skladowe specular, oddzielone spacja: ".format(texture))
                                replacing = (old_specular, new_specular)
                                replacings.append(replacing)
                                logging.info("New replacing definition was created.: {}".format(replacing))

                                texture_cache[texture] = new_specular
                                logging.info("A binding was stored in cache: ({}: {}) ".format(texture, new_specular))
                            else:
                                replacing = (old_specular, texture_cache[texture])
                                replacings.append(replacing)
                                logging.info("New replacing definition was created using cache: {}".format(replacing))
                            textures_in_order.append(texture)
                logging.info("END OF THE MODEL\n")
            with open(filepath) as input_file, open(output_filepath, "w") as output_file:
                count = 0
                for line in input_file:
                    if "specular" in line.lower():
                        line = line.replace(replacings[count][0], replacings[count][1])
                    if "map" in line.lower():
                        texture_name = line.split(":")[1].strip()
                        line = line.replace(texture_name, texture_cache[texture_name])
                        count +=1
                    output_file.write(line)
